@@ -105,7 +105,7 @@ def _perform_sync_operation(
         console.print("[bold red]✗[/bold red] Constitution required")
         console.print(f"[red]{constitution_error}[/red]")
         console.print("\n[bold yellow]Next Steps:[/bold yellow]")
-        console.print("1. Run 'specfact constitution bootstrap --repo .' to auto-generate constitution")
+        console.print("1. Run 'specfact bridge constitution bootstrap --repo .' to auto-generate constitution")
         console.print("2. Or run tool-specific constitution command in your AI assistant")
         console.print("3. Then run 'specfact sync bridge --adapter <adapter>' again")
         raise typer.Exit(1)
@@ -113,7 +113,7 @@ def _perform_sync_operation(
     # Check if constitution is minimal and suggest bootstrap
     constitution_path = repo / ".specify" / "memory" / "constitution.md"
     if constitution_path.exists():
-        from specfact_cli.commands.constitution import is_constitution_minimal
+        from specfact_cli.commands.bridge import is_constitution_minimal
 
         if is_constitution_minimal(constitution_path):
             # Auto-generate in test mode, prompt in interactive mode
@@ -145,12 +145,14 @@ def _perform_sync_operation(
                         console.print("[dim]Review and adjust as needed before syncing[/dim]")
                     else:
                         console.print(
-                            "[dim]Skipping bootstrap. Run 'specfact constitution bootstrap' manually if needed[/dim]"
+                            "[dim]Skipping bootstrap. Run 'specfact bridge constitution bootstrap' manually if needed[/dim]"
                         )
                 else:
                     # Non-interactive mode: skip prompt
                     console.print("[yellow]⚠[/yellow] Constitution is minimal (essentially empty)")
-                    console.print("[dim]Run 'specfact constitution bootstrap --repo .' to generate constitution[/dim]")
+                    console.print(
+                        "[dim]Run 'specfact bridge constitution bootstrap --repo .' to generate constitution[/dim]"
+                    )
 
     console.print("[bold green]✓[/bold green] Constitution found and validated")
 
@@ -457,6 +459,46 @@ def _perform_sync_operation(
     console.print()
     console.print("[bold green]✓[/bold green] Sync complete!")
 
+    # Auto-validate OpenAPI/AsyncAPI specs with Specmatic (if found)
+    import asyncio
+
+    from specfact_cli.integrations.specmatic import check_specmatic_available, validate_spec_with_specmatic
+
+    spec_files = []
+    for pattern in [
+        "**/openapi.yaml",
+        "**/openapi.yml",
+        "**/openapi.json",
+        "**/asyncapi.yaml",
+        "**/asyncapi.yml",
+        "**/asyncapi.json",
+    ]:
+        spec_files.extend(repo.glob(pattern))
+
+    if spec_files:
+        console.print(f"\n[cyan]🔍 Found {len(spec_files)} API specification file(s)[/cyan]")
+        is_available, error_msg = check_specmatic_available()
+        if is_available:
+            for spec_file in spec_files[:3]:  # Validate up to 3 specs
+                console.print(f"[dim]Validating {spec_file.relative_to(repo)} with Specmatic...[/dim]")
+                try:
+                    result = asyncio.run(validate_spec_with_specmatic(spec_file))
+                    if result.is_valid:
+                        console.print(f"  [green]✓[/green] {spec_file.name} is valid")
+                    else:
+                        console.print(f"  [yellow]⚠[/yellow] {spec_file.name} has validation issues")
+                        if result.errors:
+                            for error in result.errors[:2]:  # Show first 2 errors
+                                console.print(f"    - {error}")
+                except Exception as e:
+                    console.print(f"  [yellow]⚠[/yellow] Validation error: {e!s}")
+            if len(spec_files) > 3:
+                console.print(
+                    f"[dim]... and {len(spec_files) - 3} more spec file(s) (run 'specfact spec validate' to validate all)[/dim]"
+                )
+        else:
+            console.print(f"[dim]💡 Tip: Install Specmatic to validate API specs: {error_msg}[/dim]")
+
 
 def _sync_speckit_to_specfact(
     repo: Path, converter: Any, scanner: Any, progress: Any, task: int | None = None
@@ -623,6 +665,7 @@ def _sync_speckit_to_specfact(
 
 @app.command("bridge")
 def sync_bridge(
+    # Target/Input
     repo: Path = typer.Option(
         Path("."),
         "--repo",
@@ -631,16 +674,12 @@ def sync_bridge(
         file_okay=False,
         dir_okay=True,
     ),
-    adapter: str = typer.Option(
-        "speckit",
-        "--adapter",
-        help="Adapter type (speckit, generic-markdown). Default: auto-detect",
-    ),
     bundle: str | None = typer.Option(
         None,
         "--bundle",
         help="Project bundle name for SpecFact → tool conversion (default: auto-detect)",
     ),
+    # Behavior/Options
     bidirectional: bool = typer.Option(
         False,
         "--bidirectional",
@@ -656,17 +695,23 @@ def sync_bridge(
         "--watch",
         help="Watch mode for continuous sync",
     ),
+    ensure_compliance: bool = typer.Option(
+        False,
+        "--ensure-compliance",
+        help="Validate and auto-enrich plan bundle for tool compliance before sync",
+    ),
+    # Advanced/Configuration
+    adapter: str = typer.Option(
+        "speckit",
+        "--adapter",
+        help="Adapter type (speckit, generic-markdown). Default: auto-detect",
+    ),
     interval: int = typer.Option(
         5,
         "--interval",
         help="Watch interval in seconds (default: 5)",
         min=1,
     ),
-    ensure_compliance: bool = typer.Option(
-        False,
-        "--ensure-compliance",
-        help="Validate and auto-enrich plan bundle for tool compliance before sync",
-    ),
 ) -> None:
     """
     Sync changes between external tool artifacts and SpecFact using bridge architecture.
@@ -678,9 +723,15 @@ def sync_bridge(
     - speckit: Spec-Kit projects (specs/, .specify/)
     - generic-markdown: Generic markdown-based specifications
 
-    Example:
+    **Parameter Groups:**
+    - **Target/Input**: --repo, --bundle
+    - **Behavior/Options**: --bidirectional, --overwrite, --watch, --ensure-compliance
+    - **Advanced/Configuration**: --adapter, --interval
+
+    **Examples:**
         specfact sync bridge --adapter speckit --repo . --bidirectional
         specfact sync bridge --repo . --bidirectional  # Auto-detect adapter
+        specfact sync bridge --repo . --watch --interval 10
     """
     # Auto-detect adapter if not specified
     from specfact_cli.sync.bridge_probe import BridgeProbe
@@ -1033,3 +1084,233 @@ def sync_repository(
         else:
             console.print("[bold green]✓[/bold green] No deviations detected")
         console.print("[bold green]✓[/bold green] Repository sync complete!")
+
+        # Auto-validate OpenAPI/AsyncAPI specs with Specmatic (if found)
+        import asyncio
+
+        from specfact_cli.integrations.specmatic import check_specmatic_available, validate_spec_with_specmatic
+
+        spec_files = []
+        for pattern in [
+            "**/openapi.yaml",
+            "**/openapi.yml",
+            "**/openapi.json",
+            "**/asyncapi.yaml",
+            "**/asyncapi.yml",
+            "**/asyncapi.json",
+        ]:
+            spec_files.extend(resolved_repo.glob(pattern))
+
+        if spec_files:
+            console.print(f"\n[cyan]🔍 Found {len(spec_files)} API specification file(s)[/cyan]")
+            is_available, error_msg = check_specmatic_available()
+            if is_available:
+                for spec_file in spec_files[:3]:  # Validate up to 3 specs
+                    console.print(f"[dim]Validating {spec_file.relative_to(resolved_repo)} with Specmatic...[/dim]")
+                    try:
+                        result = asyncio.run(validate_spec_with_specmatic(spec_file))
+                        if result.is_valid:
+                            console.print(f"  [green]✓[/green] {spec_file.name} is valid")
+                        else:
+                            console.print(f"  [yellow]⚠[/yellow] {spec_file.name} has validation issues")
+                            if result.errors:
+                                for error in result.errors[:2]:  # Show first 2 errors
+                                    console.print(f"    - {error}")
+                    except Exception as e:
+                        console.print(f"  [yellow]⚠[/yellow] Validation error: {e!s}")
+                if len(spec_files) > 3:
+                    console.print(
+                        f"[dim]... and {len(spec_files) - 3} more spec file(s) (run 'specfact spec validate' to validate all)[/dim]"
+                    )
+            else:
+                console.print(f"[dim]💡 Tip: Install Specmatic to validate API specs: {error_msg}[/dim]")
+
+
+@app.command("intelligent")
+@beartype
+@require(
+    lambda bundle: bundle is None or (isinstance(bundle, str) and len(bundle) > 0),
+    "Bundle name must be None or non-empty string",
+)
+@require(lambda repo: isinstance(repo, Path), "Repository path must be Path")
+@ensure(lambda result: result is None, "Must return None")
+def sync_intelligent(
+    # Target/Input
+    bundle: str | None = typer.Argument(
+        None, help="Project bundle name (e.g., legacy-api). Default: active plan from 'specfact plan select'"
+    ),
+    repo: Path = typer.Option(
+        Path("."),
+        "--repo",
+        help="Path to repository. Default: current directory (.)",
+        exists=True,
+        file_okay=False,
+        dir_okay=True,
+    ),
+    # Behavior/Options
+    watch: bool = typer.Option(
+        False,
+        "--watch",
+        help="Watch mode for continuous sync. Default: False",
+    ),
+    code_to_spec: str = typer.Option(
+        "auto",
+        "--code-to-spec",
+        help="Code-to-spec sync mode: 'auto' (AST-based) or 'off'. Default: auto",
+    ),
+    spec_to_code: str = typer.Option(
+        "llm-prompt",
+        "--spec-to-code",
+        help="Spec-to-code sync mode: 'llm-prompt' (generate prompts) or 'off'. Default: llm-prompt",
+    ),
+    tests: str = typer.Option(
+        "specmatic",
+        "--tests",
+        help="Test generation mode: 'specmatic' (contract-based) or 'off'. Default: specmatic",
+    ),
+) -> None:
+    """
+    Continuous intelligent bidirectional sync with conflict resolution.
+
+    Detects changes via hashing and syncs intelligently:
+    - Code→Spec: AST-based automatic sync (CLI can do)
+    - Spec→Code: LLM prompt generation (CLI orchestrates, LLM writes)
+    - Spec→Tests: Specmatic flows (contract-based, not LLM guessing)
+
+    **Parameter Groups:**
+    - **Target/Input**: bundle (required argument), --repo
+    - **Behavior/Options**: --watch, --code-to-spec, --spec-to-code, --tests
+
+    **Examples:**
+        specfact sync intelligent legacy-api --repo .
+        specfact sync intelligent my-bundle --repo . --watch
+        specfact sync intelligent my-bundle --repo . --code-to-spec auto --spec-to-code llm-prompt --tests specmatic
+    """
+    from rich.console import Console
+
+    from specfact_cli.utils.structure import SpecFactStructure
+
+    console = Console()
+
+    # Use active plan as default if bundle not provided
+    if bundle is None:
+        bundle = SpecFactStructure.get_active_bundle_name(repo)
+        if bundle is None:
+            console.print("[bold red]✗[/bold red] Bundle name required")
+            console.print("[yellow]→[/yellow] Use --bundle option or run 'specfact plan select' to set active plan")
+            raise typer.Exit(1)
+        console.print(f"[dim]Using active plan: {bundle}[/dim]")
+
+    from specfact_cli.sync.change_detector import ChangeDetector
+    from specfact_cli.sync.code_to_spec import CodeToSpecSync
+    from specfact_cli.sync.spec_to_code import SpecToCodeSync
+    from specfact_cli.sync.spec_to_tests import SpecToTestsSync
+    from specfact_cli.telemetry import telemetry
+    from specfact_cli.utils.bundle_loader import load_project_bundle
+    from specfact_cli.utils.structure import SpecFactStructure
+
+    repo_path = repo.resolve()
+    bundle_dir = SpecFactStructure.project_dir(base_path=repo_path, bundle_name=bundle)
+
+    if not bundle_dir.exists():
+        console.print(f"[bold red]✗[/bold red] Project bundle not found: {bundle_dir}")
+        raise typer.Exit(1)
+
+    telemetry_metadata = {
+        "bundle": bundle,
+        "watch": watch,
+        "code_to_spec": code_to_spec,
+        "spec_to_code": spec_to_code,
+        "tests": tests,
+    }
+
+    with telemetry.track_command("sync.intelligent", telemetry_metadata) as record:
+        console.print(f"[bold cyan]Intelligent Sync:[/bold cyan] {bundle}")
+        console.print(f"[dim]Repository:[/dim] {repo_path}")
+
+        # Load project bundle
+        project_bundle = load_project_bundle(bundle_dir)
+
+        # Initialize sync components
+        change_detector = ChangeDetector(bundle, repo_path)
+        code_to_spec_sync = CodeToSpecSync(repo_path)
+        spec_to_code_sync = SpecToCodeSync(repo_path)
+        spec_to_tests_sync = SpecToTestsSync(bundle, repo_path)
+
+        def perform_sync() -> None:
+            """Perform one sync cycle."""
+            console.print("\n[cyan]Detecting changes...[/cyan]")
+
+            # Detect changes
+            changeset = change_detector.detect_changes(project_bundle.features)
+
+            if not any([changeset.code_changes, changeset.spec_changes, changeset.test_changes]):
+                console.print("[dim]No changes detected[/dim]")
+                return
+
+            # Report changes
+            if changeset.code_changes:
+                console.print(f"[cyan]Code changes:[/cyan] {len(changeset.code_changes)}")
+            if changeset.spec_changes:
+                console.print(f"[cyan]Spec changes:[/cyan] {len(changeset.spec_changes)}")
+            if changeset.test_changes:
+                console.print(f"[cyan]Test changes:[/cyan] {len(changeset.test_changes)}")
+            if changeset.conflicts:
+                console.print(f"[yellow]⚠ Conflicts:[/yellow] {len(changeset.conflicts)}")
+
+            # Sync code→spec (AST-based, automatic)
+            if code_to_spec == "auto" and changeset.code_changes:
+                console.print("\n[cyan]Syncing code→spec (AST-based)...[/cyan]")
+                try:
+                    code_to_spec_sync.sync(changeset.code_changes, bundle)
+                    console.print("[green]✓[/green] Code→spec sync complete")
+                except Exception as e:
+                    console.print(f"[red]✗[/red] Code→spec sync failed: {e}")
+
+            # Sync spec→code (LLM prompt generation)
+            if spec_to_code == "llm-prompt" and changeset.spec_changes:
+                console.print("\n[cyan]Preparing LLM prompts for spec→code...[/cyan]")
+                try:
+                    context = spec_to_code_sync.prepare_llm_context(changeset.spec_changes, repo_path)
+                    prompt = spec_to_code_sync.generate_llm_prompt(context)
+
+                    # Save prompt to file
+                    prompts_dir = repo_path / ".specfact" / "prompts"
+                    prompts_dir.mkdir(parents=True, exist_ok=True)
+                    prompt_file = prompts_dir / f"{bundle}-code-generation-{len(changeset.spec_changes)}.md"
+                    prompt_file.write_text(prompt, encoding="utf-8")
+
+                    console.print(f"[green]✓[/green] LLM prompt generated: {prompt_file}")
+                    console.print("[yellow]Execute this prompt with your LLM to generate code[/yellow]")
+                except Exception as e:
+                    console.print(f"[red]✗[/red] LLM prompt generation failed: {e}")
+
+            # Sync spec→tests (Specmatic)
+            if tests == "specmatic" and changeset.spec_changes:
+                console.print("\n[cyan]Generating tests via Specmatic...[/cyan]")
+                try:
+                    spec_to_tests_sync.sync(changeset.spec_changes, bundle)
+                    console.print("[green]✓[/green] Test generation complete")
+                except Exception as e:
+                    console.print(f"[red]✗[/red] Test generation failed: {e}")
+
+        if watch:
+            console.print("[bold cyan]Watch mode enabled[/bold cyan]")
+            console.print("[dim]Watching for changes...[/dim]")
+            console.print("[yellow]Press Ctrl+C to stop[/yellow]\n")
+
+            from specfact_cli.sync.watcher import SyncWatcher
+
+            def sync_callback(_changes: list) -> None:
+                """Handle file changes and trigger sync."""
+                perform_sync()
+
+            watcher = SyncWatcher(repo_path, sync_callback, interval=5)
+            try:
+                watcher.watch()
+            except KeyboardInterrupt:
+                console.print("\n[yellow]Stopping watch mode...[/yellow]")
+        else:
+            perform_sync()
+
+        record({"sync_completed": True})
